@@ -34,7 +34,7 @@ from com.dtmilano.android.concertina import Concertina
 from com.dtmilano.android.keyevent import KEY_EVENT
 from com.dtmilano.android.viewclient import ViewClient, View
 
-__version__ = '21.5.0'
+__version__ = '21.11.0'
 
 import sys
 import threading
@@ -114,6 +114,7 @@ class Operation:
     DEFAULT = 'default'
     DRAG = 'drag'
     DUMP = 'dump'
+    DUMP_UI_AUTOMATOR_HELPER = 'dum_ui_automator_helper'
     FLING_BACKWARD = 'fling_backward'
     FLING_FORWARD = 'fling_forward'
     FLING_TO_BEGINNING = 'fling_to_beginning'
@@ -146,6 +147,7 @@ class Operation:
     SLEEP = 'sleep'
     SWIPE_UI_AUTOMATOR_HELPER = 'swipe_ui_automator_helper'
     TRAVERSE = 'traverse'
+    TRAVERSE_UI_AUTOMATOR_HELPER = 'traverse_ui_automator_helper'
     VIEW_SNAPSHOT = 'view_snapshot'
     WAIT_FOR_IDLE_UI_AUTOMATOR_HELPER = 'wait_for_idle_ui_automator_helper'
     WAIT_FOR_WINDOW_UPDATE_UI_AUTOMATOR_HELPER = 'wait_for_window_update_ui_automator_helper'
