@@ -20,7 +20,7 @@ limitations under the License.
 
 from __future__ import print_function
 
-__version__ = '21.5.0'
+__version__ = '21.11.0'
 
 import json
 import os
@@ -30,7 +30,9 @@ import subprocess
 import sys
 import threading
 import time
+import warnings
 from abc import ABC
+from typing import Optional
 
 import culebratester_client
 from culebratester_client import Text, ObjectRef, StatusResponse
@@ -248,6 +250,46 @@ class UiAutomatorHelper:
             """
             return self.uiAutomatorHelper.api_instance.device_display_real_size_get()
 
+        def dumpsys(self, service, **kwargs) -> str:
+            """
+            :see https://github.com/dtmilano/CulebraTester2-public/blob/master/openapi.yaml
+            :param service: the service
+            :return: the dumpsys output
+            """
+            return self.uiAutomatorHelper.api_instance.device_dumpsys_get(service=service, _preload_content=False,
+                                                                          **kwargs).read().decode('UTF-8')
+
+        def get_top_activity_name_and_pid(self) -> Optional[str]:
+            dat = self.dumpsys('activity', arg1='top')
+            activityRE = re.compile(r'\s*ACTIVITY ([A-Za-z0-9_.]+)/([A-Za-z0-9_.\$]+) \w+ pid=(\d+)')
+            m = activityRE.findall(dat)
+            if len(m) > 0:
+                return m[-1]
+            else:
+                warnings.warn("NO MATCH:" + dat)
+                return None
+
+        def get_top_activity_name(self) -> Optional[str]:
+            tanp = self.get_top_activity_name_and_pid()
+            if tanp:
+                return tanp[0] + '/' + tanp[1]
+            else:
+                return None
+
+        def get_top_activity_uri(self) -> Optional[str]:
+            tan = self.get_top_activity_name()
+            dat = self.dumpsys('activity')
+            startActivityRE = re.compile(r'^\s*mStartActivity:')
+            intentRE = re.compile(f'^\\s*Intent {{ act=(\\S+) dat=(\\S+) flg=(\\S+) cmp={tan} }}')
+            lines = dat.splitlines()
+            for n, _line in enumerate(lines):
+                if startActivityRE.match(_line):
+                    for i in range(n, n + 6):
+                        m = intentRE.match(lines[i])
+                        if m:
+                            return m.group(2)
+            return None
+
         def wait_for_new_toast(self, timeout=10000):
             """
             :see https://github.com/dtmilano/CulebraTester2-public/blob/master/openapi.yaml
@@ -374,12 +416,18 @@ class UiAutomatorHelper:
         def find_objects(self, **kwargs):
             """
             Finds objects.
+            Invokes GET or POST method depending on the arguments passed.
 
             :see https://github.com/dtmilano/CulebraTester2-public/blob/master/openapi.yaml
             :param kwargs:
             :return:
             """
-            return self.uiAutomatorHelper.api_instance.ui_device_find_objects_get(**kwargs)
+            if 'body' in kwargs:
+                return self.uiAutomatorHelper.api_instance.ui_device_find_objects_post(**kwargs)
+            if 'by_selector' in kwargs:
+                return self.uiAutomatorHelper.api_instance.ui_device_find_objects_get(**kwargs)
+            body = culebratester_client.Selector(**kwargs)
+            return self.uiAutomatorHelper.api_instance.ui_device_find_objects_post(body=body)
 
         def press_back(self):
             """
@@ -433,18 +481,30 @@ class UiAutomatorHelper:
             body = culebratester_client.SwipeBody(**kwargs)
             return self.uiAutomatorHelper.api_instance.ui_device_swipe_post(body=body)
 
-        def take_screenshot(self, scale=1.0, quality=90, **kwargs):
+        def take_screenshot(self, scale=1.0, quality=90, filename=None, **kwargs):
             """
             Takes screenshot.
+            Eventually save it in a file specified by filename.
 
             :see https://github.com/dtmilano/CulebraTester2-public/blob/master/openapi.yaml
-            :param scale:
-            :param quality:
-            :param kwargs:
-            :return:
+            :param scale: the scale
+            :param quality: the quality
+            :param filename: if specified the image will be saved in filename
+            :param kwargs: optional arguments
+            :return: the response containing the image binary if the filename was not specified
             """
-            return self.uiAutomatorHelper.api_instance.ui_device_screenshot_get(scale=scale, quality=quality,
-                                                                                _preload_content=False, **kwargs)
+            if filename:
+                img = self.uiAutomatorHelper.api_instance.ui_device_screenshot_get(scale=scale,
+                                                                                   quality=quality,
+                                                                                   _preload_content=False,
+                                                                                   **kwargs).read()
+                with open(filename, 'wb') as file:
+                    file.write(img)
+                return
+            return self.uiAutomatorHelper.api_instance.ui_device_screenshot_get(scale=scale,
+                                                                                quality=quality,
+                                                                                _preload_content=False,
+                                                                                **kwargs)
 
         def wait(self, search_condition_ref: int, timeout=10000):
             """
@@ -527,7 +587,16 @@ class UiAutomatorHelper:
             :param oid: the oid
             :return: the content
             """
-            return self.uiAutomatorHelper.api_instance.ui_object2_dump_get(oid=oid)
+            return self.uiAutomatorHelper.api_instance.ui_object2_oid_dump_get(oid=oid)
+
+        def get_content_description(self, oid):
+            """
+            Returns the content description for this object.
+            :see https://github.com/dtmilano/CulebraTester2-public/blob/master/openapi.yaml
+            :param oid: the oid
+            :return: the text
+            """
+            return self.uiAutomatorHelper.api_instance.ui_object2_oid_get_content_description_get(oid=oid)
 
         def get_text(self, oid):
             """
@@ -794,12 +863,14 @@ class UiObject2:
     """
     A UiObject2 represents a UI element. Unlike UiObject, it is bound to a particular view instance and can become
     stale.
+    :deprecated:
     """
 
     def __init__(self, uiAutomatorHelper: UiAutomatorHelper, class_name: str, oid: int):
         """
         Constructor.
 
+        :deprecated:
         :param uiAutomatorHelper: the uiAutomatorHelper instance.
         :param class_name: the class name of the UI object
         :param oid: the object id
@@ -811,6 +882,7 @@ class UiObject2:
     def clear(self):
         """
         Clears the text content if this object is an editable field.
+        :deprecated:
         :return: the result of the operation
         """
         return self.uiAutomatorHelper.ui_object2.clear(oid=self.oid)
@@ -818,6 +890,7 @@ class UiObject2:
     def click(self):
         """
         Clicks on this object.
+        :deprecated:
         :return: the result of the operation
         """
         return self.uiAutomatorHelper.ui_object2.click(oid=self.oid)
@@ -825,12 +898,14 @@ class UiObject2:
     def dump(self):
         """
         Dumps the content of the object/
+        :deprecated:
         :return: the content of the object
         """
         return self.uiAutomatorHelper.ui_object2.dump(oid=self.oid)
 
     def get_text(self):
         """
+        :deprecated:
         Returns the text value for this object.
         :return: the text
         """
@@ -839,6 +914,7 @@ class UiObject2:
     def long_click(self):
         """
         Performs a long click on this object.
+        :deprecated:
         :return: the result of the operation
         """
         return self.uiAutomatorHelper.ui_object2.long_click(oid=self.oid)
@@ -846,6 +922,7 @@ class UiObject2:
     def set_text(self, text):
         """
         Sets the text content if this object is an editable field.
+        :deprecated:
         :param text: the text
         :return: the result of the operation
         """
